@@ -106,6 +106,10 @@ class SheinProductSku(Base):
     total_sale_volume = Column(Integer, nullable=True, comment='今日总销量')
     c7d_sale_cnt = Column(Integer, nullable=True, comment='7日销量')
     c30d_sale_cnt = Column(Integer, nullable=True, comment='30日销量')
+    old_c7d_sale_cnt = Column(Integer, nullable=True, comment='更新前的7日销量')
+    old_c30d_sale_cnt = Column(Integer, nullable=True, comment='更新前的30日销量')
+    sale_cnt_updated_at = Column(DateTime, nullable=True, comment='销量更新时间')
+    old_sale_cnt_updated_at = Column(DateTime, nullable=True, comment='旧销量更新时间')
 
     # 价格成本信息
     price = Column(DECIMAL(10, 2), nullable=True, comment='价格')
@@ -318,8 +322,14 @@ class SheinProductManager:
             existing_sku.supplier_sku = sku_data.get('supplierSku')
             existing_sku.order_cnt = sku_data.get('orderCnt')
             existing_sku.total_sale_volume = sku_data.get('totalSaleVolume')
+            # 保存旧的销量数据和更新时间
+            existing_sku.old_c7d_sale_cnt = existing_sku.c7d_sale_cnt
+            existing_sku.old_c30d_sale_cnt = existing_sku.c30d_sale_cnt
+            existing_sku.old_sale_cnt_updated_at = existing_sku.sale_cnt_updated_at
+            # 更新新的销量数据和更新时间
             existing_sku.c7d_sale_cnt = sku_data.get('c7dSaleCnt')
             existing_sku.c30d_sale_cnt = sku_data.get('c30dSaleCnt')
+            existing_sku.sale_cnt_updated_at = datetime.now()
             existing_sku.price = sku_data.get('price')
             existing_sku.erp_cost_price = sku_data.get('erp_cost_price')
             existing_sku.erp_supplier_name = sku_data.get('erp_supplier_name')
@@ -338,6 +348,7 @@ class SheinProductManager:
                 total_sale_volume=sku_data.get('totalSaleVolume'),
                 c7d_sale_cnt=sku_data.get('c7dSaleCnt'),
                 c30d_sale_cnt=sku_data.get('c30dSaleCnt'),
+                sale_cnt_updated_at=datetime.now(),
                 price=sku_data.get('price'),
                 erp_cost_price=sku_data.get('erp_cost_price'),
                 erp_supplier_name=sku_data.get('erp_supplier_name')
