@@ -224,6 +224,9 @@ class ZiniaoBrowser:
         if str(r.get("statusCode")) == "0":
             print(r)
             # return r.get("browserList", [])
+            if platform_name == "1688":
+               return [site for site in r.get("browserList", []) if '1688' in site.get('tags')]
+
             return [site for site in r.get("browserList", []) if site.get("platform_name") == platform_name]
         elif str(r.get("statusCode")) == "-10003":
             print(f"login Err {json.dumps(r, ensure_ascii=False)}")
@@ -468,6 +471,7 @@ class ZiniaoRunner:
                 just_store_username: Optional[List[str]] = None,
                 is_skip_store: Optional[Callable] = None,
                 platform_name: Optional[str] = "SHEIN-全球",
+                threads_num: int = 3,
                 ):
         """主执行入口"""
         # 前置执行 if run_prepare:
@@ -487,9 +491,10 @@ class ZiniaoRunner:
         if not browser_list:
             print("browser list is empty")
             raise RuntimeError("店铺列表为空")
+        print(browser_list)
 
         # 多线程并发执行任务
-        max_threads = 3 if (hostname().lower() == 'krrpa' or hostname().lower() == 'jyrpa') else 3
+        max_threads = 1 if (hostname().lower() == 'krrpa' or hostname().lower() == 'jyrpa') else threads_num
         log(f'当前启用线程数: {max_threads}')
         self.task_manager.run_with_thread_pool(browser_list, max_threads, run, task_key, just_store_username, is_skip_store)
 
